@@ -21,17 +21,17 @@ diags_dict['[NII] 121m/20.5m'] = ('N2', 'L(1214747)/L(2054427)', 'RMS([E(2054427
 diags_dict['[NIII] 1751+/57.4m'] = ('N3', 'B("1751A+")/L(574000)', 'RMS([E(574000), BE("1751A+")])')
 #diags_dict[''] = ('N3','L(1749)/L(1752)','RMS([E(1749), E(1752)])')
 diags_dict['[OI] 63m/147m'] = ('O1', 'L(632000)/L(1455000)', 'RMS([E(632000), E(1455000)])')
-diags_dict['[OI] 5579/6302'] = ('O1', 'L(5579)/L(6300)', 'RMS([E(6300), E(5579)])')
-diags_dict['[OI] 5579/6300'] = ('O1', 'L(5579)/L(6300)', 'RMS([E(6300), E(5579)])')
-diags_dict['[OI] 5579/6300+'] = ('O1', 'L(5579)/(L(6300)+L(6364))', 'RMS([E(6300)*L(6300)/(L(6300)+L(6364)), E(6364)*L(6364)/(L(6300)+L(6364)), E(5579)])')
+diags_dict['[OI] 5577/6302'] = ('O1', 'L(5577)/L(6300)', 'RMS([E(6300), E(5577)])')
+diags_dict['[OI] 5577/6300'] = ('O1', 'L(5577)/L(6300)', 'RMS([E(6300), E(5577)])')
+diags_dict['[OI] 5577/6300+'] = ('O1', 'L(5577)/(L(6300)+L(6364))', 'RMS([E(6300)*L(6300)/(L(6300)+L(6364)), E(6364)*L(6364)/(L(6300)+L(6364)), E(5577)])')
 diags_dict['[OII] 3726/3729'] = ('O2', 'L(3726)/L(3729)', 'RMS([E(3729), E(3726)])')
 diags_dict['[OII] 3727+/7325+'] = ('O2', '(L(3726)+L(3729))/(B("7319A+")+B("7330A+"))',
               'RMS([E(3726)*L(3726)/(L(3726)+L(3729)), E(3729)*L(3729)/(L(3726)+L(3729)),BE("7319A+")*B("7319A+")/(B("7319A+")+B("7330A+")),BE("7330A+")*B("7330A+")/(B("7319A+")+B("7330A+"))])')
 #diags_dict['[OII] 3727+/7325+'] = ('O2', '(L(3726)+L(3729))/(B("7325A+"))', 'RMS([E(3726)*L(3726)/(L(3726)+L(3729)), E(3729)*L(3729)/(L(3726)+L(3729)),BE("7325A+")])')
 diags_dict['[OIII] 4363/5007'] = ('O3', 'L(4363)/L(5007)', 'RMS([E(5007), E(4363)])')
 diags_dict['[OIII] 4363/5007+'] = ('O3', 'L(4363)/(L(5007)+L(4959))', 'RMS([E(5007)*L(5007)/(L(5007)+L(4959)), E(4959)*L(4959)/(L(5007)+L(4959)), E(4363)])')
-diags_dict['[OIII] 5007/88m'] = ('O3', 'L(5007)/L(876000)', 'RMS([E(876000), E(5007)])')
-diags_dict['[OIII] 51m/88m'] = ('O3', 'L(518000)/L(876000)', 'RMS([E(876000), E(518000)])')
+diags_dict['[OIII] 5007/88m'] = ('O3', 'L(5007)/L(883000)', 'RMS([E(883000), E(5007)])')
+diags_dict['[OIII] 51m/88m'] = ('O3', 'L(518000)/L(883000)', 'RMS([E(883000), E(518000)])')
 diags_dict['[OIII] 1666/5007+'] = ('O3', 'L(1666)/(L(5007)+L(4959))', 'RMS([E(5007)*L(5007)/(L(5007)+L(4959)), E(4959)*L(4959)/(L(5007)+L(4959)), E(1666)])')
 diags_dict['[OIII] 1666/5007'] = ('O3', 'L(1666)/L(5007)', 'RMS([E(5007), E(1666)])')
 diags_dict['[OIII] 1664+/5007'] = ('O3', '(B("1664A+"))/L(5007)', 'RMS([BE("1664A+"), E(5007)])')
@@ -52,7 +52,7 @@ diags_dict['[NeIII] 3869/15.6m'] = ('Ne3', 'L(3869)/L(156000)', 'RMS([E(156000),
 diags_dict['[NeIII] 3930+/15.6m'] = ('Ne3', '(L(3869)+L(3968))/L(156000)', 'RMS([E(156000), E(3869)*L(3869)/(L(3869)+L(3968)), E(3968)*L(3968)/(L(3869)+L(3968))])')
 diags_dict['[NeIII] 3344/3930+'] = ('Ne3', 'L(3343)/(L(3869)+L(3968))', 'RMS([E(3869)*L(3869)/(L(3869)+L(3968)), E(3968)*L(3968)/(L(3869)+L(3968)), E(3343)])')
 diags_dict['[NeIII] 3343/3930+'] = ('Ne3', 'L(3343)/(L(3869)+L(3968))', 'RMS([E(3869)*L(3869)/(L(3869)+L(3968)), E(3968)*L(3968)/(L(3869)+L(3968)), E(3343)])')
-diags_dict['[NeV] 2975/3370+'] = ('Ne5', 'L(2975)/(L(3426)+L(3346))', 'RMS([E(3426)*L(3426)/(L(3426)+L(3346)), E(3346)*L(3346)/(L(3426)+L(3346)), E(2975)])')
+diags_dict['[NeV] 2973/3370+'] = ('Ne5', 'L(2973)/(L(3426)+L(3346))', 'RMS([E(3426)*L(3426)/(L(3426)+L(3346)), E(3346)*L(3346)/(L(3426)+L(3346)), E(2973)])')
 diags_dict['[NeV] 1575/3426'] = ('Ne5', 'L(1575)/L(3426)', 'RMS([E(1575), E(3426)])')
 diags_dict['[NeV] 14.3m/24.2m'] = ('Ne5', 'L(143000)/L(242000)', 'RMS([E(143000), E(242000)])')
 diags_dict['[NeV] 3426/24.2m'] = ('Ne5', 'L(3426)/L(242000)', 'RMS([E(3426), E(242000)])')
@@ -117,6 +117,33 @@ diags_dict['[FeIII] 4703/4735'] = ('Fe3', 'L(4703)/L(4735)', 'RMS([E(4703), E(47
 diags_dict['[FeIII] 4703/4009'] = ('Fe3', 'L(4703)/L(4009)', 'RMS([E(4703), E(4009)])')
 diags_dict['[FeIII] 4735/4009'] = ('Fe3', 'L(4735)/L(4009)', 'RMS([E(4735), E(4009)])')
 diags_dict['[FeIII] 4659+/4987+'] = ('Fe3', '(L(4659)+L(4735)+L(4009))/(L(4987)+L(4989))', 'RMS([E(4659), E(4987)])')
+diags_dict['[NiIII] 6000/7890'] = ('Ni3', 'L(6000)/L(7890)', 'RMS([E(6000), E(7890)])')
+diags_dict['[NiIII] 6401/7890'] = ('Ni3', 'L(6401)/L(7890)', 'RMS([E(6401), E(7890)])')
+diags_dict['[NiIII] 6534/7890'] = ('Ni3', 'L(6534)/L(7890)', 'RMS([E(6534), E(7890)])')
+diags_dict['[NiIII] 6682/7890'] = ('Ni3', 'L(6682)/L(7890)', 'RMS([E(6682), E(7890)])')
+diags_dict['[NiIII] 6797/7890'] = ('Ni3', 'L(6797)/L(7890)', 'RMS([E(6797), E(7890)])')
+diags_dict['[NiIII] 6946/7890'] = ('Ni3', 'L(6946)/L(7890)', 'RMS([E(6946), E(7890)])')
+diags_dict['[NiIII] 6000/8500'] = ('Ni3', 'L(6000)/L(8500)', 'RMS([E(6000), E(8500)])')
+diags_dict['[NiIII] 6401/8500'] = ('Ni3', 'L(6401)/L(8500)', 'RMS([E(6401), E(8500)])')
+diags_dict['[NiIII] 6534/8500'] = ('Ni3', 'L(6534)/L(8500)', 'RMS([E(6534), E(8500)])')
+diags_dict['[NiIII] 6682/8500'] = ('Ni3', 'L(6682)/L(8500)', 'RMS([E(6682), E(8500)])')
+diags_dict['[NiIII] 6797/8500'] = ('Ni3', 'L(6797)/L(8500)', 'RMS([E(6797), E(8500)])')
+diags_dict['[NiIII] 6946/8500'] = ('Ni3', 'L(6946)/L(8500)', 'RMS([E(6946), E(8500)])')
+diags_dict['[NiIII] 6000/7125'] = ('Ni3', 'L(6000)/L(7125)', 'RMS([E(6000), E(7125)])')
+diags_dict['[NiIII] 6401/7125'] = ('Ni3', 'L(6401)/L(7125)', 'RMS([E(6401), E(7125)])')
+diags_dict['[NiIII] 6534/7125'] = ('Ni3', 'L(6534)/L(7125)', 'RMS([E(6534), E(7125)])')
+diags_dict['[NiIII] 6682/7125'] = ('Ni3', 'L(6682)/L(7125)', 'RMS([E(6682), E(7125)])')
+diags_dict['[NiIII] 6797/7125'] = ('Ni3', 'L(6797)/L(7125)', 'RMS([E(6797), E(7125)])')
+diags_dict['[NiIII] 6946/7125'] = ('Ni3', 'L(6946)/L(7125)', 'RMS([E(6946), E(7125)])')
+diags_dict['[NiIII] 6000/6401'] = ('Ni3', 'L(6000)/L(6401)', 'RMS([E(6000), E(6401)])')
+diags_dict['[NiIII] 6534/6401'] = ('Ni3', 'L(6534)/L(6401)', 'RMS([E(6534), E(6401)])')
+diags_dict['[NiIII] 6946/6401'] = ('Ni3', 'L(6946)/L(6401)', 'RMS([E(6946), E(6401)])')
+diags_dict['[NiIII] 6000/6797'] = ('Ni3', 'L(6000)/L(6797)', 'RMS([E(6000), E(6797)])')
+diags_dict['[NiIII] 6534/6797'] = ('Ni3', 'L(6534)/L(6797)', 'RMS([E(6534), E(6797)])')
+diags_dict['[NiIII] 6946/6797'] = ('Ni3', 'L(6946)/L(6797)', 'RMS([E(6946), E(6797)])')
+diags_dict['[NiIII] 6000/6682'] = ('Ni3', 'L(6000)/L(6682)', 'RMS([E(6000), E(6682)])')
+diags_dict['[NiIII] 6534/6682'] = ('Ni3', 'L(6534)/L(6682)', 'RMS([E(6534), E(6682)])')
+diags_dict['[NiIII] 6946/6682'] = ('Ni3', 'L(6946)/L(6682)', 'RMS([E(6946), E(6682)])')
 
 class Diagnostics(object):
     """
@@ -370,7 +397,7 @@ class Diagnostics(object):
             self.log_.error('the parameter must be a dictionary.', calling=self.calling + '.setAtoms')
             return None
         for atom in atom_dic:
-            if not isinstance(atom_dic[atom], pn.Atom):
+            if not isinstance(atom_dic[atom], pn.Atom) and not isinstance(atom_dic[atom], pn.RecAtom):
                 self.log_.error('the parameter must be a dictionary of Atom.', calling=self.calling + '.setAtoms')
                 return None
         self.atomDict = atom_dic
@@ -472,7 +499,7 @@ class Diagnostics(object):
                     diag_value = eval(diag[1])
                 except:
                     diag_value = None
-                    self.log_.warn('No line for diag {0}, using {1} {2}'.format(diag[1], sym, spec),
+                    self.log_.warn('A line in diagnostic {0} of {1}{2} is missing'.format(diag[1], sym, spec),
                                    calling=self.calling)
                 if diag_value is not None and not np.isnan(diag_value) and not np.isinf(diag_value):
                     def E(wave):
@@ -531,7 +558,7 @@ class Diagnostics(object):
         - value_den  value of the density-sensitive diagnostic
         - obs        np.Observation object. Values for observed temperature and density diagnostics are
                         taken from it if value_tem and value_den are None
-        - i_obs      indice of the observations to be used from obs. 
+        - i_obs      index of the observations to be used from obs. 
                         If None, all the observations are considered.
                         May be a boolean array
         - guess_tem  temperature assumed in the first iteration, in K
@@ -591,7 +618,7 @@ class Diagnostics(object):
                 value_tem = eval(eval_tem)
                 #pn.log_.debug('to eval = {0}'.format(value_tem), calling=calling + 'TEST')
             except:
-                pn.log_.warn(' no value for {0} {1}: {2} in obs'.format(elem_tem, spec_tem, diag_tem), calling=calling)
+                pn.log_.warn('No value for {0} {1}: {2} in obs'.format(elem_tem, spec_tem, diag_tem), calling=calling)
                 return None
         else:
             if type(value_tem) == type([]): value_tem = np.asarray(value_tem)
@@ -620,7 +647,7 @@ class Diagnostics(object):
                 value_den = eval(eval_den)
                 #pn.log_.debug('to eval = {0}'.format(value_den), calling=calling + ' TEST1')
             except:
-                pn.log_.warn(' no value for {0} {1}: {2} in obs'.format(elem_den, spec_den, diag_den), calling=calling)
+                pn.log_.warn('No value for {0} {1}: {2} in obs'.format(elem_den, spec_den, diag_den), calling=calling)
                 return None
         else:
             if type(value_den) == type([]): value_den = np.asarray(value_den)
@@ -629,7 +656,7 @@ class Diagnostics(object):
         
         tem = atom_tem.getTemDen(value_tem, den=den, to_eval=eval_tem,
                                  maxError=maxError, start_x=start_tem, end_x=end_tem)
-#        self.log_.debug('tem: ' + str(tem) + ' den :' + str(den), calling='getCrossTemDen')
+#        self.log_.debug('tem: ' + str(tem) + ' den:' + str(den), calling='getCrossTemDen')
         no_conv = np.ones_like(den).astype(bool)
         n_tot = np.asarray(value_tem).size
         for i in np.arange(max_iter):
@@ -677,4 +704,6 @@ class Diagnostics(object):
         to_eval = self.diags[diag][1]
         HDR = atom.getHighDensRatio(to_eval = to_eval)
         LDR = atom.getLowDensRatio(to_eval = to_eval)
-        return(np.sort((LDR, HDR)))
\ No newline at end of file
+        return(np.sort((LDR, HDR)))
+    
+    
\ No newline at end of file
